#!/usr/bin/env python

# Rapache - Apache Configuration Tool
# Copyright (C) 2008 Stefano Forenza,  Jason Taylor, Emanuele Gentili
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

SYSCONFDIR = '/etc/apache2'
SITES_ENABLED_DIR = SYSCONFDIR + '/sites-enabled'
SITES_AVAILABLE_DIR = SYSCONFDIR + '/sites-available'
MODS_ENABLED_DIR = SYSCONFDIR + '/mods-enabled'
MODS_AVAILABLE_DIR = SYSCONFDIR + '/mods-available'
APPPATH = '/usr/bin' #please fill at run-time
GLADEPATH = '/usr/share/rapache/Glade' #please fill at run-time
NUMBER_OF_BACKUPS = 10
TEST_CONNECTION_INTERVAL = 30
